@@ -31,9 +31,10 @@ import (
 	"regexp"
 	"strings"
 
+	"github.com/docker/docker/api/types/container"
+
 	"github.com/docker/cli/cli/command"
 	"github.com/docker/cli/cli/flags"
-	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/filters"
 	"github.com/docker/docker/client"
 	"github.com/docker/docker/pkg/archive"
@@ -79,7 +80,7 @@ func (d Docker) CopyToNode(ctx context.Context, src string, dest string, node *k
 	}
 	defer docker.Close()
 
-	container, err := getNodeContainer(ctx, node)
+	nodeContainer, err := getNodeContainer(ctx, node)
 	if err != nil {
 		return fmt.Errorf("failed to find container for target node '%s': %w", node.Name, err)
 	}
@@ -98,7 +99,7 @@ func (d Docker) CopyToNode(ctx context.Context, src string, dest string, node *k
 
 	destInfo := archive.CopyInfo{Path: dest}
 
-	destStat, _ := docker.ContainerStatPath(ctx, container.ID, dest) // don't blame me, docker is also not doing anything if err != nil ¯\_(ツ)_/¯
+	destStat, _ := docker.ContainerStatPath(ctx, nodeContainer.ID, dest) // don't blame me, docker is also not doing anything if err != nil ¯\_(ツ)_/¯
 
 	destInfo.Exists, destInfo.IsDir = true, destStat.Mode.IsDir()
 
@@ -108,7 +109,7 @@ func (d Docker) CopyToNode(ctx context.Context, src string, dest string, node *k
 	}
 	defer preparedArchive.Close()
 
-	return docker.CopyToContainer(ctx, container.ID, destDir, preparedArchive, types.CopyToContainerOptions{AllowOverwriteDirWithFile: false})
+	return docker.CopyToContainer(ctx, nodeContainer.ID, destDir, preparedArchive, container.CopyToContainerOptions{AllowOverwriteDirWithFile: false})
 }
 
 // WriteToNode writes a byte array to the selected node
@@ -147,7 +148,7 @@ func (d Docker) WriteToNode(ctx context.Context, content []byte, dest string, mo
 	}
 
 	tarBytes := bytes.NewReader(buf.Bytes())
-	if err := docker.CopyToContainer(ctx, nodeContainer.ID, "/", tarBytes, types.CopyToContainerOptions{AllowOverwriteDirWithFile: true}); err != nil {
+	if err := docker.CopyToContainer(ctx, nodeContainer.ID, "/", tarBytes, container.CopyToContainerOptions{AllowOverwriteDirWithFile: true}); err != nil {
 		return fmt.Errorf("Failed to copy content to container '%s': %+v", nodeContainer.ID, err)
 	}
 
